fsleyes-widgets
===============

The `fsleyes-widgets` package contains a collection of GUI widgets and
utilities, based on [wxPython](http://www.wxpython.org). These widgets are
used by `fsleyes-props` and `fsleyes`.


All of the dependencies of `fsleyes-widgets` are listed in the
[requirements.txt](requirements.txt) file.


Documentation
-------------

`fsleyes-widgets` is documented using
[sphinx](http://http://sphinx-doc.org/). You can build the API documentation
by running:

    python setup.py doc

The HTML documentation will be generated and saved in the `doc/html/` directory.


Contributing
------------

If you would like to contribute to `fsleyes-widgets`, take a look at the
`fslpy` [contributing
guide](https://git.fmrib.ox.ac.uk/fsl/fslpy/blob/master/doc/contributing.rst).